import os
from distutils.core import setup

setup_pars = {
    "packages" : [
        'csst_dfs_api',
        'csst_dfs_api.common',
        'csst_dfs_api.cpic',
        'csst_dfs_api.facility',
        'csst_dfs_api.functional',
        'csst_dfs_api.hstdm',
        'csst_dfs_api.ifs',
        'csst_dfs_api.mbi',
        'csst_dfs_api.mci',
        'csst_dfs_api.sls',
    ],
    "package_dir" : {
        'csst_dfs_api' : 'csst_dfs_api',
        'csst_dfs_api.common' : 'csst_dfs_api/common',
        'csst_dfs_api.cpic' : 'csst_dfs_api/cpic',
        'csst_dfs_api.facility' : 'csst_dfs_api/facility',
        'csst_dfs_api.functional' : 'csst_dfs_api/functional',
        'csst_dfs_api.hstdm' : 'csst_dfs_api/hstdm',
        'csst_dfs_api.ifs' : 'csst_dfs_api/ifs',
        'csst_dfs_api.mbi' : 'csst_dfs_api/mbi',
        'csst_dfs_api.mci' : 'csst_dfs_api/mci',
        'csst_dfs_api.sls' : 'csst_dfs_api/sls',
    },
}
def requirements():
    with open("requirements.txt", "r") as f:
        return [
            req.strip()
            for req in f.readlines()
            if not req.startswith("#") and req.__contains__("==")
        ]

def version():
    __version = {}
    version_path = os.path.join(os.path.dirname(__file__), "csst_dfs_api", "version.py")
    with open(version_path, "r") as file:
        exec(file.read(), __version)
    return __version["__version__"]

setup(
    name="csst_dfs_api",
    version=version(),
    description="API's to access CSST Data Flow System (DFS)",
    long_description=open('README.md').read(),
    license="MIT",
    python_requires=">=3.7",
    install_requires=requirements(),
    zip_safe=False,
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Science/Research",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Topic :: Scientific/Engineering :: Physics",
        "Topic :: Scientific/Engineering :: Astronomy",

    ],
    include_package_data=False,
    project_urls={
        'Source': 'https://csst-tb.bao.ac.cn/code/csst-dfs/csst-dfs-api',
    },
    **setup_pars
)
